# [BraineryWiz](https://www.silviasbrainery.com/brainerywiz)

[![PyPI version fury.io](https://badge.fury.io/py/BraineryWiz.svg)](https://pypi.python.org/pypi/BraineryWiz/)
[![Downloads](https://pepy.tech/badge/BraineryWiz)](https://pepy.tech/project/BraineryWiz)
[![Downloads](https://pepy.tech/badge/BraineryWiz/month)](https://pepy.tech/project/BraineryWiz)
[![Downloads](https://pepy.tech/badge/BraineryWiz/week)](https://pepy.tech/project/BraineryWiz)

**LinkedIn Page**: https://www.linkedin.com/company/brainerywiz

**Main WebPage**: https://www.silviasbrainery.com/brainerywiz

**Documentation**: https://silvia-s-brainery.github.io/BraineryWizDocumentation/

**BraineyWiz Email Address:** <BraineryWiz@Gmail.com>


**Description:**

***An Element Independent Package for plotting FEM models***

## By: 

- **Bijan Sayyafzadeh**: [Github](https://github.com/BijanSeif), Email: <B.Sayyaf@yahoo.com>
- **Silvia Mazzoni**: [Github](https://github.com/silviamazzoni), Email: <SilviaMazzoni@yahoo.com>

## Programming Ethics : (Responsibility about Users Privacy)
This is **Bijan Sayyafzadeh**, Because this package is not an opensource code, by this text I state that **I'm the main developer and responsible of all code lines of this package** and it is stated by me that the program has been written by completely respect to the users privacy and their data and their privacy and there is no collection, monitoring, and exchange of users personal information and data in this package and I am the main responsible of this ethical statement. This statement is valid for both Python and TCL (BraineryWiz.exe) version for all the time.
